#include <algorithm>
#include <iostream>
#include <map>
#include <vector>
#ifndef dbg
#define dbg(...)
#endif

using namespace std;

struct SegmTree {
  int n;
  vector<int> t;

  SegmTree(int n_) : n(n_) {
    int sz = 1;
    while (sz < n)
      sz *= 2;
    t.resize(2 * sz);
  }

  void Update(int node, int left, int right, int pos, int val) {
    if (left + 1 == right) {
      t[node] += val;
      return;
    }

    int mid = (left + right) / 2;
    if (pos < mid)
      Update(2 * node + 1, left, mid, pos, val);
    else
      Update(2 * node + 2, mid, right, pos, val);
    t[node] = t[2 * node + 1] + t[2 * node + 2];
  }

  int Query(int node, int left, int right, int pos) {
    if (right <= pos)
      return t[node];
    int mid = (left + right) / 2;
    if (pos <= mid) {
      return Query(2 * node + 1, left, mid, pos);
    }
    return Query(2 * node + 1, left, mid, pos) +
           Query(2 * node + 2, mid, right, pos);
  }

  void Update(int pos, int val) { Update(0, 0, n, pos, val); }

  int Query(int pos) { return Query(0, 0, n, pos + 1); }
};

int main() {
  ios::sync_with_stdio(0);
  cin.tie(0);

  int p; cin >> p;
  int n;
  cin >> n;
  vector<int64_t> v(n - 1);
  map<int64_t, int> m;
  int64_t prev;
  cin >> prev;
  int64_t sum = prev;
  for (int i = 0; i < n - 1; ++i) {
    int64_t curr;
    cin >> curr;
    v[i] = curr - prev;
    prev = curr;
    m[v[i]] = 0;
  }

  int index = 0;
  for (auto &p : m) {
    p.second = index++;
  }

  auto u = v;
  sort(u.begin(), u.end());
  int64_t curr_sum = sum;
  for (int i = 0; i < n - 1; ++i) {
    curr_sum += u[i];
    sum += curr_sum;
  }

  for (int i = 0; i < n - 1; ++i) {
    v[i] = m[v[i]];
  }
  dbg(v);
  SegmTree st(index);
  int64_t inversions = 0;
  for (int i = 0; i < n - 1; ++i) {
    int curr = index - v[i] - 1;
    if (curr > 0)
      inversions += st.Query(curr - 1);
    dbg(i, curr, inversions);
    st.Update(curr, +1);
  }

  cout << (p == 1 ? sum : inversions) << endl;
}
